# Command line tools
This page documents the program usage for ``lewis`` and ``lewis-control``, the two command line
tools provided as part of a Lewis installation.

## lewis
See {py:meth}`lewis.scripts.run`

## lewis-control
See {py:meth}`lewis.scripts.control`
